@@ -23,6 +23,7 @@ from airflow.kubernetes.volume import Volume
 from airflow.kubernetes.volume_mount import VolumeMount
 from airflow.contrib.operators.kubernetes_pod_operator import KubernetesPodOperator
 from airflow.operators.dummy_operator import DummyOperator
+from airflow.contrib.kubernetes.pod import Port
 
 from liminal.runners.airflow.config.standalone_variable_backend import get_variable
 from liminal.runners.airflow.model import task
@@ -145,18 +146,17 @@ class PythonTask(task.Task):
         kubernetes_kwargs = {
             'namespace': get_variable('kubernetes_namespace', default_val='default'),
             'name': self.task_name.replace('_', '-'),
-            'in_cluster': get_variable('in_kubernetes_cluster', default_val=False),
+            'in_cluster': False,
             'image_pull_policy': get_variable('image_pull_policy', default_val='IfNotPresent'),
             'get_logs': True,
-            'is_delete_operator_pod': True,
+            'is_delete_operator_pod': False,
             'startup_timeout_seconds': 300,
             'image_pull_secrets': 'regcred',
             'resources': self.resources,
             'dag': self.dag,
-            'do_xcom_push': get_variable('do_xcom_push', default_val=True),
             'volumes': self.volumes,
-            'config_file': get_variable('kube_config_path', default_val='~/.kube/config'),
-            'cluster_context': get_variable('cluster_context', default_val=None),
+            'config_file': '/usr/local/airflow/dags/kube_config.yaml',
+            'cluster_context': 'aws',
             'volume_mounts': [
                 VolumeMount(mount['volume'],
                             mount['path'],
